@@ -2,6 +2,7 @@
 
 import json
 
+
 class list:
     def __init__(self, json_file, info):
         self.code = None
@@ -22,11 +23,12 @@ class list:
             # print(self.error)
             return self.error
         else:
-            db = json.load(open(self.file))
+            db = json.load(open(self.file, encoding="utf-8"))
             num = 0
             for name in db["name"]:
-                num +=1
+                num += 1
                 print(str(num), ":", name)
             choose = input(str(self.info))
             commands = db["command"]
             exec(commands[int(int(choose)-1)])
+            return 20000
